/*
 * This software is the confidential and proprietary information of
 * Smardec. You shall not disclose or distribute such Confidential Information.
 * This software shall not be integrated, copied (partially or fully),
 * or reverse engineered into any other software, program, or code that is
 * not intended for Smardec. You shall use it only in accordance with the terms
 * of the license agreement you entered into with Smardec.
 *
 * Copyright (C) 2004-2006 Smardec. All rights reserved.
 *
 * http://www.smardec.com
 *
 */

package com.smardec.demo.j2native.linux.usermanager.info;

import com.smardec.demo.j2native.tools.Cachable;

import java.util.ArrayList;
import java.util.List;


public class UserInfo implements Cachable {
    public static final String ACCOUNT_LOCK_SIGNATURE = "!!";
    public static final String SYSTEM_ACCOUNT_SIGNATURE = "*";
    public static final int MAX_DAYS_BEFORE_CHANGE = 99999;


    private String userName;      /* Login name.  */
    private String userPass;      /* Encrypted password. */
    private int dateOfLastChange; /* Date of last change. */
    private int minDaysChange;    /* Minimum number of days between changes. */
    private int maxDaysChange;    /* Maximum number of days between changes. */
    private int daysToWarn;       /* Number of days to warn user to change the password. */

    private int daysInactive;     /* Number of days the account may be inactive. */
    private int daysExpire;       /* Number of days since 1970-01-01 until account expires. */
    private int userId;           /* user id */
    private int groupId;          /* group id */
    private String realName;      /* real name */
    private String homeDir;       /* home directory */
    private String shellPrg;      /* shell program */
    private List groups;          /* user groups */

    public UserInfo(String userName, int userId) {
        this.userName = userName;
        this.userId = userId;
    }

    protected UserInfo(UserInfo uiOriginal) {
        this(uiOriginal.getUserName(), uiOriginal.getId());

        this.userPass = uiOriginal.getUserPass();
        this.dateOfLastChange = uiOriginal.getDateOfLastChange();
        this.minDaysChange = uiOriginal.getMinDaysChange();
        this.maxDaysChange = uiOriginal.getMaxDaysChange();
        this.daysToWarn = uiOriginal.getDaysToWarn();
        this.daysInactive = uiOriginal.getDaysInactive();
        this.daysExpire = uiOriginal.getDaysExpire();
        this.groupId = uiOriginal.getGroupId();
        this.realName = uiOriginal.getRealName();
        this.homeDir = uiOriginal.getHomeDir();
        this.shellPrg = uiOriginal.getShellPrg();

        List groupList = uiOriginal.getGroups();
        this.groups = new ArrayList();
        for (int i = groupList.size() - 1; i >= 0; i--) {
            this.groups.add(GroupInfo.clone(groupList.get(i)));

        }
    }

    public int getId() {
        return userId;
    }

    public String getUserName() {
        return userName;
    }

    public String getIdent() {
        return getUserName();
    }

    public int getDateOfLastChange() {
        return dateOfLastChange;
    }

    public void setDateOfLastChange(int dateOfLastChange) {
        this.dateOfLastChange = dateOfLastChange;
    }

    public int getDaysExpire() {
        return daysExpire;
    }

    public void setDaysExpire(int daysExpire) {
        this.daysExpire = daysExpire;
    }

    public boolean isAccountExpire() {
        return daysExpire != -1;
    }

    public boolean isAccountLocked() {
        if (getUserPass() == null) {
            return false;
        }
        if (getUserPass().startsWith(ACCOUNT_LOCK_SIGNATURE) || ("".equals((getUserPass())))) {
            return true;
        }
        return false;
    }

    public boolean isPassExpEnabled() {
        return (getMinDaysChange() != -1) && (getMaxDaysChange() != MAX_DAYS_BEFORE_CHANGE) && (getDaysToWarn() != -1);
    }

    public int getDaysInactive() {
        return daysInactive;
    }

    public void setDaysInactive(int daysInactive) {
        this.daysInactive = daysInactive;
    }

    public int getDaysToWarn() {
        return daysToWarn;
    }

    public void setDaysToWarn(int daysToWarn) {
        this.daysToWarn = daysToWarn;
    }

    public List getGroups() {
        return groups;
    }

    public void setGroups(List groups) {
        this.groups = groups;
    }

    public String getHomeDir() {
        return homeDir;
    }

    public void setHomeDir(String homeDir) {
        this.homeDir = homeDir;
    }

    public int getMaxDaysChange() {
        return maxDaysChange;
    }

    public void setMaxDaysChange(int maxDaysChange) {
        this.maxDaysChange = maxDaysChange;
    }

    public int getMinDaysChange() {
        return minDaysChange;
    }

    public void setMinDaysChange(int minDaysChange) {
        this.minDaysChange = minDaysChange;
    }

    public String getRealName() {
        return realName;
    }

    public void setRealName(String realName) {
        this.realName = realName;
    }

    public String getShellPrg() {
        return shellPrg;
    }

    public void setShellPrg(String shellPrg) {
        this.shellPrg = shellPrg;
    }

    public String getUserPass() {
        return userPass;
    }

    public void setUserPass(String userPass) {
        this.userPass = userPass;
    }

    public int getGroupId() {
        return groupId;
    }

    public void setGroupId(int groupId) {
        this.groupId = groupId;
    }

    public static UserInfo clone(UserInfo uiOriginal) {
        if (uiOriginal != null) {
            return new UserInfo((UserInfo) uiOriginal);
        }
        return null;
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        } else if (obj instanceof UserInfo) {
            return getId() == ((UserInfo) obj).getId();
        }
        return false;
    }

}
